# File Conversion

::: fdtdx.core.conversion.load_stl.load_stl
::: fdtdx.core.conversion.export.export_stl
<!-- ::: fdtdx.core.conversion.export.export_mask_to_gds -->
::: fdtdx.core.conversion.export.idx_to_xyz
::: fdtdx.core.conversion.export.xyz_to_idx
::: fdtdx.core.conversion.import_utils.gds_to_numpy
